[tbb-commits] [tor-browser-build/master] Bug 40105: Enhance Gradle dependency script

sysrqb at torproject.org sysrqb at torproject.org
Wed Sep 23 13:00:04 UTC 2020


commit 4f9ab234282887c8b0394da8ef9a5b8802afa863
Author: Georg Koppen <gk at torproject.org>
Date:   Tue Sep 22 12:02:59 2020 +0000

    Bug 40105: Enhance Gradle dependency script
    
    We sort now in a way that makes the output reproducible on different
    machines and exclude .module files, too, as we do not need them.
---
 tools/gen_gradle_deps_file.sh | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/tools/gen_gradle_deps_file.sh b/tools/gen_gradle_deps_file.sh
index 377676f..99d0517 100755
--- a/tools/gen_gradle_deps_file.sh
+++ b/tools/gen_gradle_deps_file.sh
@@ -38,12 +38,13 @@
 #    having made a copy of `gradle-dependencies-list.txt` from 1) and comparing
 #    the two .txt files.
 
+export LC_ALL=C
 log="$1"
 
 # Step 1: Extract all the download attempts out of the log file, ignore the ones
 # for maven-metadata.xml files. We don't need those.
 cat $log | grep "Performing HTTP" | grep -o "https://.*" | \
-  grep -v "maven-metadata.xml" | sort | uniq > dl-attempts
+  grep -vE "\.module|maven-metadata\.xml" | sort | uniq > dl-attempts
 
 # Step 2: Fetch all the dependencies and calculate the SHA-256 sum
 while read line
@@ -38,12 +38,13 @@
 
 # Step 1: Extract all the download attempts out of the log file, ignore the ones
-# for maven-metadata.xml files. We don't need those.
+# for maven-metadata.xml and module files. We don't need those.
 cat $log | grep "Performing HTTP" | grep -o "https://.*" | \





More information about the tbb-commits mailing list